@@ -26,7 +26,7 @@
 #include <config.h>
 #include <stdio.h>
 #include <string.h>
-#include "gdk-pixbuf.h"
+#include "gdk-pixbuf-private.h"
 
 #if (G_BYTE_ORDER == G_LITTLE_ENDIAN)
 #define LITTLE
@@ -35,7 +35,7 @@
 
 
 
-static unsigned long mask_table[] = {
+static guint32 mask_table[] = {
 	0x00000000, 0x00000001, 0x00000003, 0x00000007,
 	0x0000000f, 0x0000001f, 0x0000003f, 0x0000007f,
 	0x000000ff, 0x000001ff, 0x000003ff, 0x000007ff,
@@ -54,15 +54,15 @@ static unsigned long mask_table[] = {
   no alpha
 */
 static void
-rgb1 (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb1 (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
-	unsigned char *s;
-	register unsigned char data;
-	unsigned char *o;
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint8 *s;
+	register guint8 data;
+	guint8 *o;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	d (printf ("1 bits/pixel\n"));
 
@@ -93,16 +93,16 @@ rgb1 (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
   with alpha
 */
 static void
-rgb1a (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb1a (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
-	unsigned char *s;
-	register unsigned char data;
-	unsigned char *o;
-	unsigned char *srow = image->mem, *orow = pixels;
-	unsigned long remap[2];
+	guint8 *s;
+	register guint8 data;
+	guint8 *o;
+	guint8 *srow = image->mem, *orow = pixels;
+	guint32 remap[2];
 
 	d (printf ("1 bits/pixel\n"));
 
@@ -145,16 +145,16 @@ rgb1a (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
   no alpha
 */
 static void
-rgb8 (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb8 (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
-	unsigned long mask;
-	register unsigned long data;
-	unsigned char *srow = image->mem, *orow = pixels;
-	register unsigned char *s;
-	register unsigned char *o;
+	guint32 mask;
+	register guint32 data;
+	guint8 *srow = image->mem, *orow = pixels;
+	register guint8 *s;
+	register guint8 *o;
 
 	width = image->width;
 	height = image->height;
@@ -183,17 +183,17 @@ rgb8 (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
   with alpha
 */
 static void
-rgb8a (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb8a (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
-	unsigned long mask;
-	register unsigned long data;
-	unsigned long remap[256];
-	register unsigned char *s;	/* read 2 pixels at once */
-	register unsigned long *o;
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint32 mask;
+	register guint32 data;
+	guint32 remap[256];
+	register guint8 *s;	/* read 2 pixels at once */
+	register guint32 *o;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -219,7 +219,7 @@ rgb8a (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
 
 	for (yy = 0; yy < height; yy++) {
 		s = srow;
-		o = (unsigned long *) orow;
+		o = (guint32 *) orow;
 		for (xx = 0; xx < width; xx ++) {
 			data = *s++ & mask;
 			*o++ = remap[data];
@@ -235,19 +235,19 @@ rgb8a (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
   data in lsb format
 */
 static void
-rgb565lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb565lsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned long *s;	/* read 2 pixels at once */
+	register guint32 *s;	/* read 2 pixels at once */
 #else
-	register unsigned char *s;	/* read 2 pixels at once */
+	register guint8 *s;	/* read 2 pixels at once */
 #endif
-	register unsigned short *o;
-	unsigned char *srow = image->mem, *orow = pixels;
+	register guint16 *o;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -255,13 +255,13 @@ rgb565lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 
 	for (yy = 0; yy < height; yy++) {
 #ifdef LITTLE
-		s = (unsigned long *) srow;
+		s = (guint32 *) srow;
 #else
-		s = (unsigned char *) srow;
+		s = (guint32 *) srow;
 #endif
-		o = (unsigned short *) orow;
+		o = (guint16 *) orow;
 		for (xx = 1; xx < width; xx += 2) {
-			register unsigned long data;
+			register guint32 data;
 #ifdef LITTLE
 			data = *s++;
 			*o++ = (data & 0xf800) >> 8 | (data & 0x7e0) << 5;
@@ -278,7 +278,7 @@ rgb565lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 		}
 		/* check for last remaining pixel */
 		if (width & 1) {
-			register unsigned short data;
+			register guint16 data;
 #ifdef LITTLE
 			data = *((short *) s);
 #else
@@ -300,19 +300,19 @@ rgb565lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
   data in msb format
 */
 static void
-rgb565msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb565msb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned char *s;	/* need to swap data order */
+	register guint8 *s;	/* need to swap data order */
 #else
-	register unsigned long *s;	/* read 2 pixels at once */
+	register guint32 *s;	/* read 2 pixels at once */
 #endif
-	register unsigned short *o;
-	unsigned char *srow = image->mem, *orow = pixels;
+	register guint16 *o;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -322,11 +322,11 @@ rgb565msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 #ifdef LITTLE
 		s = srow;
 #else
-		s = (unsigned long *) srow;
+		s = (guint32 *) srow;
 #endif
-		o = (unsigned short *) orow;
+		o = (guint16 *) orow;
 		for (xx = 1; xx < width; xx += 2) {
-			register unsigned long data;
+			register guint32 data;
 #ifdef LITTLE
 			/* swap endianness first */
 			data = s[0] | s[1] << 8 | s[2] << 16 | s[3] << 24;
@@ -343,7 +343,7 @@ rgb565msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 		}
 		/* check for last remaining pixel */
 		if (width & 1) {
-			register unsigned short data;
+			register guint16 data;
 #ifdef LITTLE
 			data = *((short *) s);
 			data = ((data >> 8) & 0xff) | ((data & 0xff) << 8);
@@ -365,20 +365,20 @@ rgb565msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
   data in lsb format
 */
 static void
-rgb565alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb565alsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned short *s;	/* read 1 pixels at once */
+	register guint16 *s;	/* read 1 pixels at once */
 #else
-	register unsigned char *s;
+	register guint8 *s;
 #endif
-	register unsigned long *o;
+	register guint32 *o;
 
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -386,13 +386,13 @@ rgb565alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 
 	for (yy = 0; yy < height; yy++) {
 #ifdef LITTLE
-		s = (unsigned short *) srow;
+		s = (guint16 *) srow;
 #else
-		s = (unsigned char *) srow;
+		s = (guint8 *) srow;
 #endif
-		o = (unsigned long *) orow;
+		o = (guint32 *) orow;
 		for (xx = 0; xx < width; xx ++) {
-			register unsigned long data;
+			register guint32 data;
 			/*  rrrrrggg gggbbbbb -> rrrrr000 gggggg00 bbbbb000 aaaaaaaa */
 			/*  little endian: aaaaaaaa bbbbb000 gggggg00 rrrrr000 */
 #ifdef LITTLE
@@ -418,20 +418,20 @@ rgb565alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
   data in msb format
 */
 static void
-rgb565amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb565amsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned char *s;
+	register guint8 *s;
 #else
-	register unsigned short *s;	/* read 1 pixels at once */
+	register guint16 *s;	/* read 1 pixels at once */
 #endif
-	register unsigned long *o;
+	register guint32 *o;
 
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -439,9 +439,9 @@ rgb565amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 
 	for (yy = 0; yy < height; yy++) {
 		s = srow;
-		o = (unsigned long *) orow;
+		o = (guint32 *) orow;
 		for (xx = 0; xx < width; xx ++) {
-			register unsigned long data;
+			register guint32 data;
 			/*  rrrrrggg gggbbbbb -> rrrrr000 gggggg00 bbbbb000 aaaaaaaa */
 			/*  little endian: aaaaaaaa bbbbb000 gggggg00 rrrrr000 */
 #ifdef LITTLE
@@ -467,19 +467,19 @@ rgb565amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
   data in lsb format
 */
 static void
-rgb555lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb555lsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned long *s;	/* read 2 pixels at once */
+	register guint32 *s;	/* read 2 pixels at once */
 #else
-	register unsigned char *s;	/* read 2 pixels at once */
+	register guint8 *s;	/* read 2 pixels at once */
 #endif
-	register unsigned short *o;
-	unsigned char *srow = image->mem, *orow = pixels;
+	register guint16 *o;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -487,13 +487,13 @@ rgb555lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 
 	for (yy = 0; yy < height; yy++) {
 #ifdef LITTLE
-		s = (unsigned long *) srow;
+		s = (guint32 *) srow;
 #else
 		s = srow;
 #endif
-		o = (unsigned short *) orow;
+		o = (guint16 *) orow;
 		for (xx = 1; xx < width; xx += 2) {
-			register unsigned long data;
+			register guint32 data;
 #ifdef LITTLE
 			data = *s++;
 			*o++ = (data & 0x7c00) >> 7 | (data & 0x3e0) << 6;
@@ -510,7 +510,7 @@ rgb555lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 		}
 		/* check for last remaining pixel */
 		if (width & 1) {
-			register unsigned short data;
+			register guint16 data;
 #ifdef LITTLE
 			data = *((short *) s);
 #else
@@ -532,19 +532,19 @@ rgb555lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
   data in msb format
 */
 static void
-rgb555msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb555msb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned char *s;	/* read 2 pixels at once */
+	register guint8 *s;	/* read 2 pixels at once */
 #else
-	register unsigned long *s;	/* read 2 pixels at once */
+	register guint32 *s;	/* read 2 pixels at once */
 #endif
-	register unsigned short *o;
-	unsigned char *srow = image->mem, *orow = pixels;
+	register guint16 *o;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -552,9 +552,9 @@ rgb555msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 
 	for (yy = 0; yy < height; yy++) {
 		s = srow;
-		o = (unsigned short *) orow;
+		o = (guint16 *) orow;
 		for (xx = 1; xx < width; xx += 2) {
-			register unsigned long data;
+			register guint32 data;
 #ifdef LITTLE
 			/* swap endianness first */
 			data = s[0] | s[1] << 8 | s[2] << 16 | s[3] << 24;
@@ -571,7 +571,7 @@ rgb555msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 		}
 		/* check for last remaining pixel */
 		if (width & 1) {
-			register unsigned short data;
+			register guint16 data;
 #ifdef LITTLE
 			data = *((short *) s);
 			data = ((data >> 8) & 0xff) | ((data & 0xff) << 8);
@@ -593,20 +593,20 @@ rgb555msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
   data in lsb format
 */
 static void
-rgb555alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb555alsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned short *s;	/* read 1 pixels at once */
+	register guint16 *s;	/* read 1 pixels at once */
 #else
-	register unsigned char *s;
+	register guint8 *s;
 #endif
-	register unsigned long *o;
+	register guint32 *o;
 
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -614,13 +614,13 @@ rgb555alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 
 	for (yy = 0; yy < height; yy++) {
 #ifdef LITTLE
-		s = (unsigned short *) srow;
+		s = (guint16 *) srow;
 #else
 		s = srow;
 #endif
-		o = (unsigned long *) orow;
+		o = (guint32 *) orow;
 		for (xx = 0; xx < width; xx++) {
-			register unsigned long data;
+			register guint32 data;
 			/*  rrrrrggg gggbbbbb -> rrrrr000 gggggg00 bbbbb000 aaaaaaaa */
 			/*  little endian: aaaaaaaa bbbbb000 gggggg00 rrrrr000 */
 #ifdef LITTLE
@@ -646,20 +646,20 @@ rgb555alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
   data in msb format
 */
 static void
-rgb555amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb555amsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
 #ifdef LITTLE
-	register unsigned short *s;	/* read 1 pixels at once */
+	register guint16 *s;	/* read 1 pixels at once */
 #else
-	register unsigned char *s;
+	register guint8 *s;
 #endif
-	register unsigned long *o;
+	register guint32 *o;
 
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -667,13 +667,13 @@ rgb555amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 
 	for (yy = 0; yy < height; yy++) {
 #ifdef LITTLE
-		s = (unsigned short *) srow;
+		s = (guint16 *) srow;
 #else
 		s = srow;
 #endif
-		o = (unsigned long *) orow;
+		o = (guint32 *) orow;
 		for (xx = 0; xx < width; xx++) {
-			register unsigned long data;
+			register guint32 data;
 			/*  rrrrrggg gggbbbbb -> rrrrr000 gggggg00 bbbbb000 aaaaaaaa */
 			/*  little endian: aaaaaaaa bbbbb000 gggggg00 rrrrr000 */
 #ifdef LITTLE
@@ -695,15 +695,15 @@ rgb555amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 
 
 static void
-rgb888alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb888alsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
-	unsigned char *s;	/* for byte order swapping */
-	unsigned char *o;
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint8 *s;	/* for byte order swapping */
+	guint8 *o;
+	guint8 *srow = image->mem, *orow = pixels;
 
 	width = image->width;
 	height = image->height;
@@ -728,14 +728,14 @@ rgb888alsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 }
 
 static void
-rgb888lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb888lsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
-	unsigned char *srow = image->mem, *orow = pixels;
-	unsigned char *o, *s;
+	guint8 *srow = image->mem, *orow = pixels;
+	guint8 *o, *s;
 
 	width = image->width;
 	height = image->height;
@@ -758,19 +758,19 @@ rgb888lsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
 }
 
 static void
-rgb888amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb888amsb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
-	unsigned char *srow = image->mem, *orow = pixels;
+	guint8 *srow = image->mem, *orow = pixels;
 #ifdef LITTLE
-	unsigned long *o;
-	unsigned long *s;
+	guint32 *o;
+	guint32 *s;
 #else
-	unsigned char *s;	/* for byte order swapping */
-	unsigned char *o;
+	guint8 *s;	/* for byte order swapping */
+	guint8 *o;
 #endif
 
 	d (printf ("32 bit, msb, with alpha\n"));
@@ -782,8 +782,8 @@ rgb888amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 	/* msb data */
 	for (yy = 0; yy < height; yy++) {
 #ifdef LITTLE
-		s = (unsigned long *) srow;
-		o = (unsigned long *) orow;
+		s = (guint32 *) srow;
+		o = (guint32 *) orow;
 #else
 		s = srow;
 		o = orow;
@@ -806,15 +806,15 @@ rgb888amsb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colorma
 }
 
 static void
-rgb888msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap)
+rgb888msb (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *colormap)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
 
-	unsigned char *srow = image->mem, *orow = pixels;
-	unsigned char *s;
-	unsigned char *o;
+	guint8 *srow = image->mem, *orow = pixels;
+	guint8 *s;
+	guint8 *o;
 
 	d (printf ("32 bit, msb, no alpha\n"));
 
@@ -841,14 +841,14 @@ rgb888msb (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *colormap
   run quite slow
 */
 static void
-convert_real_slow (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *cmap, int alpha)
+convert_real_slow (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *cmap, int alpha)
 {
 	int xx, yy;
 	int width, height;
 	int bpl;
-	unsigned char *srow = image->mem, *orow = pixels;
-	unsigned char *s;
-	unsigned char *o;
+	guint8 *srow = image->mem, *orow = pixels;
+	guint8 *s;
+	guint8 *o;
 	guint32 pixel;
 	GdkVisual *v;
 
@@ -899,7 +899,7 @@ convert_real_slow (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *
 	}
 }
 
-typedef void (* cfunc) (GdkImage *image, art_u8 *pixels, int rowstride, GdkColormap *cmap);
+typedef void (* cfunc) (GdkImage *image, guchar *pixels, int rowstride, GdkColormap *cmap);
 
 static cfunc convert_map[] = {
 	rgb1,rgb1,rgb1a,rgb1a,
@@ -917,7 +917,7 @@ static cfunc convert_map[] = {
   conversion function.
 */
 static void
-rgbconvert (GdkImage *image, art_u8 *pixels, int rowstride, int alpha, GdkColormap *cmap)
+rgbconvert (GdkImage *image, guchar *pixels, int rowstride, int alpha, GdkColormap *cmap)
 {
 	int index = (image->byte_order == GDK_MSB_FIRST) | (alpha != 0) << 1;
 	int bank=5;		/* default fallback converter */
@@ -1020,7 +1020,9 @@ rgbconvert (GdkImage *image, art_u8 *pixels, int rowstride, int alpha, GdkColorm
  * be undefined.
  *
  * Return value: The same pixbuf as @dest if it was non-NULL, or a newly-created
- * pixbuf with a reference count of 1 if no destination pixbuf was specified.
+ * pixbuf with a reference count of 1 if no destination pixbuf was specified; in
+ * the latter case, NULL will be returned if not enough memory could be
+ * allocated for the pixbuf to be created.
  **/
 GdkPixbuf *
 gdk_pixbuf_get_from_drawable (GdkPixbuf *dest,
@@ -1031,7 +1033,6 @@ gdk_pixbuf_get_from_drawable (GdkPixbuf *dest,
 {
 	GdkWindowType window_type;
 	int src_width, src_height;
-	ArtPixBuf *apb = NULL;
 	GdkImage *image;
 	int rowstride, bpp, alpha;
 
@@ -1054,11 +1055,9 @@ gdk_pixbuf_get_from_drawable (GdkPixbuf *dest,
 	if (!dest)
 		g_return_val_if_fail (dest_x == 0 && dest_y == 0, NULL);
 	else {
-		apb = dest->art_pixbuf;
-
-		g_return_val_if_fail (apb->format == ART_PIX_RGB, NULL);
-		g_return_val_if_fail (apb->n_channels == 3 || apb->n_channels == 4, NULL);
-		g_return_val_if_fail (apb->bits_per_sample == 8, NULL);
+		g_return_val_if_fail (dest->colorspace == GDK_COLORSPACE_RGB, NULL);
+		g_return_val_if_fail (dest->n_channels == 3 || dest->n_channels == 4, NULL);
+		g_return_val_if_fail (dest->bits_per_sample == 8, NULL);
 	}
 
 	/* Coordinate sanity checks */
@@ -1070,8 +1069,8 @@ gdk_pixbuf_get_from_drawable (GdkPixbuf *dest,
 
 	if (dest) {
 		g_return_val_if_fail (dest_x >= 0 && dest_y >= 0, NULL);
-		g_return_val_if_fail (dest_x + width <= apb->width, NULL);
-		g_return_val_if_fail (dest_y + height <= apb->height, NULL);
+		g_return_val_if_fail (dest_x + width <= dest->width, NULL);
+		g_return_val_if_fail (dest_y + height <= dest->height, NULL);
 	}
 
 	if (window_type != GDK_WINDOW_PIXMAP) {
@@ -1096,33 +1095,31 @@ gdk_pixbuf_get_from_drawable (GdkPixbuf *dest,
 
 	/* Get Image in ZPixmap format (packed bits). */
 	image = gdk_image_get (src, src_x, src_y, width, height);
-	g_return_val_if_fail( image != NULL, NULL);
+	g_return_val_if_fail (image != NULL, NULL);
 
 	/* Create the pixbuf if needed */
 	if (!dest) {
-		dest = gdk_pixbuf_new (ART_PIX_RGB, FALSE, 8, width, height);
+		dest = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, width, height);
 		if (!dest) {
 			gdk_image_destroy(image);
 			return NULL;
 		}
-
-		apb = dest->art_pixbuf;
 	}
 
 	/* Get the colormap if needed */
 	if (window_type != GDK_WINDOW_PIXMAP)
 		cmap = gdk_window_get_colormap (src);
 
-	alpha = gdk_pixbuf_get_has_alpha(dest);
-	rowstride = gdk_pixbuf_get_rowstride(dest);
-	bpp = alpha?4:3;
+	alpha = dest->has_alpha;
+	rowstride = dest->rowstride;
+	bpp = alpha ? 4 : 3;
 
 	/* we offset into the image data based on the position we are retrieving from */
-	rgbconvert(image, gdk_pixbuf_get_pixels(dest) +
-		   (dest_y * rowstride) + (dest_x * bpp),
-		   rowstride,
-		   alpha,
-		   cmap);
+	rgbconvert (image, dest->pixels +
+		    (dest_y * rowstride) + (dest_x * bpp),
+		    rowstride,
+		    alpha,
+		    cmap);
 
 	gdk_image_destroy(image);
 
